@@ -3,7 +3,7 @@ package Labyrinth;
 use warnings;
 use strict;
 
-our $VERSION = '5.30';
+our $VERSION = '5.31';
 
 =head1 NAME
 
@@ -105,6 +105,12 @@ sub run {
         UnPublish();                    # Start a fresh slate
         LoadSettings($file);            # Load All Global Settings
 
+        eval "use Labyrinth::Paths";
+        unless($@) {
+            my $paths = Labyrinth::Paths->new();
+            $paths->parse();
+        }
+
         die $tvars{errmess} if($tvars{errcode} && $tvars{errcode} eq 'ERROR');
 
         MailSet(mailsend => $settings{mailsend}, logdir => $settings{logdir});
